pub struct SessionStore {
pub id: String,
/* private fields */
}Fields
id: StringImplementations
Sourceimpl SessionStore
impl SessionStore
Sourcepub fn new(
root: &Path,
cwd: &Path,
id: Option<&str>,
title: Option<String>,
) -> Result<Self>
pub fn new( root: &Path, cwd: &Path, id: Option<&str>, title: Option<String>, ) -> Result<Self>
Creates a new session or loads an existing one.
If id is provided, it loads that session.
If id is None, it creates a new session.
title is used when creating a new session or updating metadata.
pub fn new_with_parent( root: &Path, cwd: &Path, id: Option<&str>, title: Option<String>, parent_session_id: Option<String>, ) -> Result<Self>
pub fn list(root: &Path, cwd: &Path) -> Result<Vec<SessionMetadata>>
pub fn list_with_options( root: &Path, cwd: &Path, include_children: bool, ) -> Result<Vec<SessionMetadata>>
pub fn update_title(&self, title: impl Into<String>) -> Result<()>
pub fn append(&self, event: &SessionEvent) -> Result<()>
pub fn replay_messages(&self) -> Result<Vec<Message>>
pub fn replay_events(&self) -> Result<Vec<SessionEvent>>
pub fn file(&self) -> &Path